@@ -3,7 +3,7 @@ package App::ZofCMS::Plugin::FileUpload;
 use warnings;
 use strict;
 
-our $VERSION = '1.001005'; # VERSION
+our $VERSION = '1.001006'; # VERSION
 
 use File::Spec::Functions (qw/catfile  splitpath/);
 
@@ -51,6 +51,12 @@ sub _process_upload {
 
     my $cgi = $config->cgi;
     my $remote_filename = $cgi->param( $upload->{query} );
+
+    if ( not $remote_filename and $cgi->cgi_error ) {
+        $template->{t}{ $error_key } = $cgi->cgi_error;
+        return;
+    }
+
     return
         unless defined $remote_filename;
 
@@ -82,6 +88,12 @@ sub _process_upload {
             $upload->{name} . $upload->{ext}
         );
     }
+    elsif ( ref $upload->{name} eq 'SCALAR' ) {
+        $upload->{name} = catfile(
+            $upload->{path},
+            ( $remote_filename =~ /([^.]+)(?:[.].+)?$/)[0] . $upload->{ext}
+        );
+    }
     else {
         $upload->{name} = catfile(
             $upload->{path},
